🔖 [Table of Contents](../../README.md) / [Concepts](../README.md) / [Task Input](README.md)

# Input

# Technical Specification

<!--start-doc-->
<!--end-doc-->

🔖 [Table of Contents](../../README.md) / [Concepts](../README.md) / [Task Input](README.md)
